@@ -5,20 +5,23 @@
 #include "bcsubwindow.h"
 #include "vframe.inc"
 
-
+#include <stdint.h>
 
 
 class BC_Button : public BC_SubWindow
 {
 public:
 	BC_Button(int x, int y, VFrame **data);
+	BC_Button(int x, int y, int w, VFrame **data);
 	virtual ~BC_Button();
 
 	friend class BC_GenericButton;
 
 	virtual int handle_event() { return 0; };
-	int repeat_event(long repeat_id);
+	int repeat_event(int64_t repeat_id);
 	virtual int draw_face();
+	void disable();
+	void enable();
 
 	int initialize();
 	virtual int set_images(VFrame **data);
@@ -29,12 +32,16 @@ public:
 	int cursor_motion_event();
 	int update_bitmaps(VFrame **data);
 	int reposition_window(int x, int y);
+	void set_underline(int number);
 
 private:
 
-	BC_Pixmap *images[9];
+	BC_Pixmap *images[3];
 	VFrame **data;
 	int status;
+	int w_argument;
+	int underline_number;
+	int enabled;
 };
 
 
@@ -43,7 +50,8 @@ private:
 class BC_GenericButton : public BC_Button
 {
 public:
-	BC_GenericButton(int x, int y, char *text);
+	BC_GenericButton(int x, int y, char *text, VFrame **data = 0);
+	BC_GenericButton(int x, int y, int w, char *text, VFrame **data = 0);
 	int set_images(VFrame **data);
 	int draw_face();
 
@@ -56,6 +64,7 @@ class BC_OKButton : public BC_Button
 public:
 	BC_OKButton(int x, int y);
 	BC_OKButton(BC_WindowBase *parent_window);
+	virtual int resize_event(int w, int h);
 	virtual int handle_event();
 	virtual int keypress_event();
 };
@@ -65,11 +74,9 @@ class BC_CancelButton : public BC_Button
 public:
 	BC_CancelButton(int x, int y);
 	BC_CancelButton(BC_WindowBase *parent_window);
+	virtual int resize_event(int w, int h);
 	virtual int handle_event();
 	virtual int keypress_event();
-	
-private:
-	BC_Pixmap *images[9];
 };
 
 #endif
