@@ -6,9 +6,12 @@
 class BC_ProgressBar : public BC_SubWindow
 {
 public:
-	BC_ProgressBar(int x, int y, int w, long length);
+	BC_ProgressBar(int x, int y, int w, long length, int do_text = 1);
+	~BC_ProgressBar();
 
 	int initialize();
+	int reposition_window(int x, int y, int w = -1, int h = -1);
+	void set_do_text(int value);
 
 	int update(long position);
 	int update_length(long length);
@@ -19,7 +22,8 @@ private:
 
 	long length, position;
 	int pixel;
-	BC_Pixmap *images[6];
+	int do_text;
+	BC_Pixmap *images[2];
 };
 
 #endif
