@@ -11,7 +11,7 @@ public:
 
 	virtual int handle_up_event() { return 0; };
 	virtual int handle_down_event() { return 0; };
-	int repeat_event(long repeat_id);
+	int repeat_event(int64_t repeat_id);
 
 	int initialize();
 	int set_images(VFrame **data);
@@ -22,28 +22,29 @@ public:
 	int cursor_motion_event();
 	int update_bitmaps(VFrame **data);
 	int reposition_window(int x, int y);
-	virtual void set_boundaries(long min, long max) {};
+	virtual void set_boundaries(int64_t min, int64_t max) {};
 	virtual void set_boundaries(float min, float max) {};
+	virtual void set_increment(float value) {};
 
 private:
 	int draw_face();
 
 	BC_Pixmap *images[4];
 	int status;
-	long repeat_count;
+	int64_t repeat_count;
 };
 
 class BC_ITumbler : public BC_Tumbler
 {
 public:
-	BC_ITumbler(BC_TextBox *textbox, long min, long max, int x, int y);
+	BC_ITumbler(BC_TextBox *textbox, int64_t min, int64_t max, int x, int y);
 	virtual ~BC_ITumbler();
-	
+
 	int handle_up_event();
 	int handle_down_event();
-	void set_boundaries(long min, long max);
+	void set_boundaries(int64_t min, int64_t max);
 
-	long min, max;
+	int64_t min, max;
 	BC_TextBox *textbox;
 };
 
@@ -56,8 +57,10 @@ public:
 	int handle_up_event();
 	int handle_down_event();
 	void set_boundaries(float min, float max);
+	void set_increment(float value);
 
 	float min, max;
+	float increment;
 	BC_TextBox *textbox;
 };
 
