@@ -7,8 +7,8 @@ class ErrorBox : public BC_Window
 {
 public:
 	ErrorBox(char *title, 
-		int x = (int)INFINITY, 
-		int y = (int)INFINITY, 
+		int x = (int)BC_INFINITY, 
+		int y = (int)BC_INFINITY, 
 		int w = 400, 
 		int h = 120);
 	virtual ~ErrorBox();
