@@ -5,10 +5,14 @@
 #include "bcbutton.h"
 #include "bcclipboard.h"
 #include "bcdragwindow.h"
+#include "bclistboxitem.h"
 #include "bcpan.h"
 #include "bcfilebox.h"
 #include "bclistbox.h"
+#include "bcmenu.h"
 #include "bcmenubar.h"
+#include "bcmenuitem.h"
+#include "bcmenupopup.h"
 #include "bcmeter.h"
 #include "bcpopupmenu.h"
 #include "bcpot.h"
@@ -18,6 +22,7 @@
 #include "bcslider.h"
 #include "bcsubwindow.h"
 #include "bctextbox.h"
+#include "bctheme.h"
 #include "bctitle.h"
 #include "bctoggle.h"
 #include "bctumble.h"
