@@ -7,15 +7,16 @@
 class Mutex
 {
 public:
-	Mutex();
+	Mutex(char *title = 0);
 	~Mutex();
 
-	int lock();
+	int lock(char *location = 0);
 	int unlock();
 	int trylock();
 	int reset();
 
 	pthread_mutex_t mutex;
+	char *title;
 };
 
 
