@@ -1,6 +1,33 @@
 #ifndef SEMA_H
 #define SEMA_H
 
+
+#include <semaphore.h>
+
+class Sema
+{
+public:
+	Sema(int init_value = 1, char *title = 0);
+	~Sema();
+
+	void lock(char *location = 0);
+	void unlock();
+	int get_value();
+
+	sem_t sem;
+	char *title;
+};
+
+
+
+
+
+
+
+
+#if 0
+
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/ipc.h>
@@ -30,7 +57,7 @@ public:
 	semun arg;
 };
 
-
+#endif
 
 
 
