@@ -2,6 +2,7 @@
 #define AUDIODEVICE_H
 
 #include "asset.inc"
+#include "condition.inc"
 #include "mutex.h"
 #include "mwindow.inc"
 #include "thread.h"
@@ -40,7 +41,6 @@ public:
 	long last_samples_written;
 	long last_position;
 	Timer timer;
-	Mutex timer_lock;
 	long actual_buffer;
 	int playing_back;
 	int current_inbuffer, current_outbuffer;
@@ -50,7 +50,9 @@ public:
 // Copy of mwindow parameter created at start
 	int mix_strategy;
 
-	Mutex input_lock[TOTAL_BUFFERS], output_lock[TOTAL_BUFFERS];
+	Mutex *timer_lock;
+	Condition *input_lock[TOTAL_BUFFERS];
+	Condition *output_lock[TOTAL_BUFFERS];
 };
 
 
