@@ -16,7 +16,7 @@ public:
 	int close_file();
 	int read_header();
 	long get_audio_length();
-	int get_position(double &percentage, double &seconds);
+	int get_position(double *percentage, double *seconds);
 	long get_audio_position();
 	int end_of_audio();
 	int end_of_video();
