@@ -16,7 +16,7 @@ public:
 	int reset();
 	int read_header();
 	long get_audio_length();
-	int get_position(double &percentage, double &seconds);
+	int get_position(double *percentage, double *seconds);
 	long get_video_position();
 	long get_audio_position();
 	int end_of_audio();
@@ -30,6 +30,7 @@ public:
 	int set_mmx(int use_mmx);
 	int colormodel_supported(int color_model);
 	int read_frame(VFrame *frame, int in_y1, int in_y2);
+	void synchronize_position(File *src);
 
 
 	int read_audio(char *buffer, long len);
