@@ -2,6 +2,7 @@
 #define PLAYBACKENGINE_H
 
 #include "arender.inc"
+#include "condition.inc"
 #include "mwindow.inc"
 #include "mwindowgui.inc"
 #include "mutex.h"
@@ -23,7 +24,7 @@ public:
 	int reset_parameters();
 	int close_playback();  // normal ending
 	int wait_for_startup();
-	int current_position(double &percentage, double &seconds);
+	int current_position(double *percentage, double *seconds);
 	void update_tracking(double tracking_position, double tracking_time);
 	long PlaybackEngine::current_sample();
 	void interrupt_playback(int wait_engine);
@@ -38,8 +39,8 @@ public:
 	int playing_back;
 	PlaybackScroll *scroll;
 	MWindow *mwindow;
-	Mutex startup_lock;
-	Mutex complete;
+	Condition *startup_lock;
+	Condition *complete;
 // Starting sample for audio-only positioning
 	long starting_sample;  
 // Time of last tracking_position update
