@@ -1,6 +1,7 @@
 #ifndef PLAYBACKSCROLL_H
 #define PLAYBACKSCROLL_H
 
+#include "condition.inc"
 #include "mutex.inc"
 #include "mwindow.inc"
 #include "thread.h"
@@ -19,8 +20,10 @@ public:
 	int start_playback();
 	int stop_playback();
 	void run();
-	
-	Mutex *pause_lock, *loop_lock, *startup_lock;
+
+	Condition *startup_lock;
+	Condition *pause_lock;
+	Mutex *loop_lock;
 	MWindow *mwindow;
 	int done;
 };
