@@ -2,6 +2,7 @@
 #define RENDERENGINE_H
 
 #include "arender.inc"
+#include "condition.inc"
 #include "mutex.inc"
 #include "mwindow.inc"
 #include "playbackengine.inc"
@@ -20,6 +21,7 @@ public:
 	void interrupt_playback(int wait_engine);
 	void run();
 	long sync_sample();
+	void reset_sync_sample();
 
 	ARender *arender;
 	VRender *vrender;
@@ -28,7 +30,8 @@ public:
 	PlaybackEngine *playback_engine;
 	Mutex *input_lock;
 	Mutex *interrupt_lock;
-	Mutex *completion_lock;
+	Condition *completion_lock;
+	Condition *first_frame_lock;
 	Timer *sync_timer;
 // Kernel side decryption is not threaded during seeking
 	Mutex *seek_lock;
