@@ -13,6 +13,12 @@ public:
 	virtual int update_positions(MWindow *mwindow, MWindowGUI *gui) { return 0; };
 	virtual void draw_canvas_bg(BC_WindowBase *canvas) {};
 	virtual void update_positions_from_canvas(MWindow *mwindow, MWindowGUI *gui) {};
+	void build_button(VFrame** &data,
+		unsigned char *png_overlay,
+		VFrame *up_vframe,
+		VFrame *hi_vframe,
+		VFrame *dn_vframe);
+	void overlay(VFrame *dst, VFrame *src);
 
 	VFrame *icon;
 	VFrame **play;
@@ -21,7 +27,7 @@ public:
 	VFrame **pause;
 // Canvas size when not fullscreen
 	int canvas_x, canvas_y, canvas_w, canvas_h;     
-	int time_x, time_y;
+	int time_x, time_y, time_w;
 	int play_x, play_y;
 	int frameback_x, frameback_y;
 	int framefwd_x, framefwd_y;
